@@ -16,11 +16,14 @@ import click
 
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
+from osducli.commands.search._const import (
+    SEARCH_SERVICE_NAME,
+    SEARCH_STATUS_PATH,
+    SEARCH_SWAGGER_PATH,
+)
 from osducli.config import CONFIG_SEARCH_URL
 from osducli.util.service_info import info
 
-from ._const import SEARCH_SERVICE_NAME, SEARCH_STATUS_PATH, SEARCH_SWAGGER_PATH
-
 
 # click entry point
 @click.command(cls=CustomClickCommand)
