@@ -23,6 +23,7 @@ from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 @click.command(cls=CustomClickCommand)
 @click.option("-k", "--kind", "kind", help="kind to search for")
 @click.option("-id", "--id", "_id", help="id to search for")
+@click.option("-q", "--query", "_query", help="custom search query")
 @click.option(
     "-l",
     "--limit",
@@ -33,13 +34,13 @@ from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 )
 @handle_cli_exceptions
 @command_with_output("results[*].{Id:id,Kind:kind,CreateTime:createTime}")
-def _click_command(state: State, kind: str, _id: str, limit: int):
-    """Query search service"""
-    return query(state, kind, _id, limit)
+def _click_command(state: State, kind: str, _id: str, _query: str, limit: int):
+    """Search using more advanced query terms"""
+    return query(state, kind, _id, _query, limit)
 
 
 def query(
-    state: State, kind: str, id: str, limit: int
+    state: State, kind: str, id: str, custom_query: str, limit: int
 ):  # pylint: disable=invalid-name,redefined-builtin
     """Query search service
 
@@ -47,8 +48,8 @@ def query(
         state (State): Global state
     """
     connection = CliOsduClient(state.config)
-
     search_client = SearchClient(connection)
-    json_response = search_client.query(kind, id, limit)
+    print(custom_query)
+    json_response = search_client.query(kind, id, custom_query, limit)
 
     return json_response
