@@ -17,16 +17,25 @@ from requests.exceptions import RequestException
 
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
+from osducli.commands.crs._const import (
+    CRS_CATALOG_SERVICE_NAME,
+    CRS_CATALOG_STATUS_PATH,
+    CRS_CONVERTER_SERVICE_NAME,
+    CRS_CONVERTER_STATUS_PATH,
+)
 from osducli.commands.entitlements._const import (
     ENTITLEMENTS_SERVICE_NAME,
     ENTITLEMENTS_STATUS_PATH,
 )
+from osducli.commands.file._const import FILE_SERVICE_NAME, FILE_STATUS_PATH
 from osducli.commands.legal._const import LEGAL_SERVICE_NAME, LEGAL_STATUS_PATH
 from osducli.commands.schema._const import SCHEMA_SERVICE_NAME, SCHEMA_STATUS_PATH
 from osducli.commands.search._const import SEARCH_SERVICE_NAME, SEARCH_STATUS_PATH
 from osducli.commands.unit._const import UNIT_SERVICE_NAME, UNIT_STATUS_PATH
 from osducli.commands.workflow._const import WORKFLOW_SERVICE_NAME, WORKFLOW_STATUS_PATH
 from osducli.config import (
+    CONFIG_CRS_CATALOG_URL,
+    CONFIG_CRS_CONVERTER_URL,
     CONFIG_ENTITLEMENTS_URL,
     CONFIG_FILE_URL,
     CONFIG_LEGAL_URL,
@@ -60,7 +69,9 @@ def status(state: State):  # pylint: disable=unused-argument
     connection = CliOsduClient(state.config)
     results = []
     services = [
-        ("File service", CONFIG_FILE_URL, "readiness_check"),
+        (CRS_CATALOG_SERVICE_NAME, CONFIG_CRS_CATALOG_URL, CRS_CATALOG_STATUS_PATH),
+        (CRS_CONVERTER_SERVICE_NAME, CONFIG_CRS_CONVERTER_URL, CRS_CONVERTER_STATUS_PATH),
+        (FILE_SERVICE_NAME, CONFIG_FILE_URL, FILE_STATUS_PATH),
         (ENTITLEMENTS_SERVICE_NAME, CONFIG_ENTITLEMENTS_URL, ENTITLEMENTS_STATUS_PATH),
         (LEGAL_SERVICE_NAME, CONFIG_LEGAL_URL, LEGAL_STATUS_PATH),
         (SCHEMA_SERVICE_NAME, CONFIG_SCHEMA_URL, SCHEMA_STATUS_PATH),
