@@ -16,11 +16,14 @@ import click
 
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
+from osducli.commands.workflow._const import (
+    WORKFLOW_SERVICE_NAME,
+    WORKFLOW_STATUS_PATH,
+    WORKFLOW_SWAGGER_PATH,
+)
 from osducli.config import CONFIG_WORKFLOW_URL
 from osducli.util.service_info import info
 
-from ._const import WORKFLOW_SERVICE_NAME, WORKFLOW_STATUS_PATH, WORKFLOW_SWAGGER_PATH
-
 
 # click entry point
 @click.command(cls=CustomClickCommand)
